### R code from vignette source 'vegdata.Rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: prep
###################################################
options(width=100,digits=2)


###################################################
### code chunk number 2: vegdata.Rnw:42-43 (eval = FALSE)
###################################################
## vignette('vegdata')


###################################################
### code chunk number 3: load
###################################################
library(vegdata)


###################################################
### code chunk number 4: vegdata.Rnw:90-91
###################################################
tv.home()


###################################################
### code chunk number 5: vegdata.Rnw:95-96 (eval = FALSE)
###################################################
## options(tv_home="path_to_your_Turboveg_root_directory")


###################################################
### code chunk number 6: vegdata.Rnw:99-100
###################################################
options(tv_home=file.path(.path.package("vegdata"),'tvdata'))


###################################################
### code chunk number 7: dblisting
###################################################
tv.db()


###################################################
### code chunk number 8: vegdata.Rnw:110-111
###################################################
tv.refl()


###################################################
### code chunk number 9: tax
###################################################
tax('Achillea millefolium')


###################################################
### code chunk number 10: vegdata.Rnw:123-124
###################################################
tax('Achillea millefolium', strict=TRUE, verbose=TRUE) 


###################################################
### code chunk number 11: syn
###################################################
tax('Elytrigia repens')$ABBREVIAT
syn('Elytrigia repens')


###################################################
### code chunk number 12: childs
###################################################
childs(27, quiet=TRUE)$ABBREVIAT
parents('ACHIMIL')


###################################################
### code chunk number 13: db
###################################################
db <- 'taxatest'


###################################################
### code chunk number 14: meta (eval = FALSE)
###################################################
## tv.metainfo(db)


###################################################
### code chunk number 15: obs
###################################################
obs.tax <- tv.obs(db)
# Adding species names
species <- tax('all', syn=TRUE)
obs.tax$Name <-  species$ABBREVIAT[match(obs.tax$SPECIES_NR, species$SPECIES_NR)]
head(obs.tax[,1:4])


###################################################
### code chunk number 16: taxval
###################################################
obs.taxval <- taxval(obs.tax, db=db, mono='lower')


###################################################
### code chunk number 17: Taxon
###################################################
obs.taxval$Taxon <-  species$ABBREVIAT[match(obs.taxval$SPECIES_NR, species$SPECIES_NR)]
obs.taxval[order(obs.taxval$Name),c('Name','Taxon')]


###################################################
### code chunk number 18: FAM
###################################################
tmp <- taxval(obs.tax, db=db, maxtaxlevel='FAM', ag='adapt', rank='FAM')
tmp$Taxon <-  species$ABBREVIAT[match(tmp$SPECIES_NR, species$SPECIES_NR)]
tmp[order(tmp$Taxon),9:10]


###################################################
### code chunk number 19: vegdata.Rnw:275-276 (eval = FALSE)
###################################################
## newtaxa <- tv.taxval(obs, db, concept='korneck1996')


###################################################
### code chunk number 20: cover
###################################################
obs <- tv.obs(db)
obs <- tv.coverperc(db, obs)
head(obs)


###################################################
### code chunk number 21: pseudo1 (eval = FALSE)
###################################################
## data(lc.0)
## tv.veg(db, pseudo = list(lc.0, c("LAYER")), lc = "layer")


###################################################
### code chunk number 22: lc0
###################################################
data(lc.0)
tmp <- tv.veg(db, tax=FALSE, pseudo = list(lc.0, "LAYER"), lc = "layer", quiet=TRUE)
names(tmp)


###################################################
### code chunk number 23: Season
###################################################
comb <- list(data.frame(SEASON=0:4, COMB=c(0,'Spring','Summer','Autumn','Winter')),'SEASON')
tv.veg(db, tax=FALSE, pseudo=comb)


###################################################
### code chunk number 24: layer
###################################################
data(lc.1)
veg <- tv.veg(db, lc = "sum", pseudo = list(lc.1, 'LAYER'), dec = 1, quiet=TRUE)


###################################################
### code chunk number 25: layerdiff
###################################################
veg[,1:10]


###################################################
### code chunk number 26: vegdata.Rnw:342-343
###################################################
obs.tax$SPECIES_NR[obs.tax$SPECIES_NR == 27] <- 31


###################################################
### code chunk number 27: replace
###################################################
taxon.repl <- data.frame(old=c(27), new=c(31))
obs.tax$SPECIES_NR <- replace(obs.tax$SPECIES_NR, match(taxon.repl$old, obs.tax$SPECIES_NR), taxon.repl$new)


###################################################
### code chunk number 28: comb.spec
###################################################
comb.species(veg, sel=c('QUERROB','QUERROB.Tree'))


###################################################
### code chunk number 29: site.echo
###################################################
site <- tv.site(db)


###################################################
### code chunk number 30: RMySQL
###################################################
library(RMySQL)


###################################################
### code chunk number 31: vegdata.Rnw:393-394
###################################################
source('http://geobot.botanik.uni-greifswald.de/download/r_package/vegetweb.r')


###################################################
### code chunk number 32: vwsite
###################################################
vw.site()


###################################################
### code chunk number 33: con (eval = FALSE)
###################################################
## con <- vw.con()
## dbListTables(con)
## url.show('http://planto.de/OekoArt/ModellLog.php')


###################################################
### code chunk number 34: vegdata.Rnw:410-413
###################################################
con <- vw.con()
dbListFields(con, "beobachtung")
dbGetQuery(con, "SELECT * FROM projekt")[1:2]


###################################################
### code chunk number 35: vegdata.Rnw:416-417
###################################################
query <- "Projekt='T302'"


###################################################
### code chunk number 36: vegdata.Rnw:423-425
###################################################
site <- vw.site(query)
site.coord <- site[!is.na(site$"Geografische Breite"),]


###################################################
### code chunk number 37: vegdata.Rnw:436-437 (eval = FALSE)
###################################################
## tv.compRefl('taxref1', 'taxref2')


###################################################
### code chunk number 38: elbaue
###################################################
data(elbaue)


###################################################
### code chunk number 39: cluster
###################################################
clust <- vector('integer', nrow(elbaue.env))
clust[elbaue.env$MGL < -50 & elbaue.env$SDGL < 50] <- 1		# dry sites, low deviation
clust[elbaue.env$MGL < -50 & elbaue.env$SDGL >= 50] <- 2	# dry sites, high deviation
clust[elbaue.env$MGL >= -50 & elbaue.env$SDGL >= 50] <- 3	# wet sites, high deviation
clust[elbaue.env$MGL >= -50 & elbaue.env$SDGL < 50] <- 4	# wet sites, low deviation
levels(clust) <- c('dry.ld','dry.hd', 'wet.hd','wet.ld')


###################################################
### code chunk number 40: syntab
###################################################
syntab(elbaue, clust, limit = 40)


###################################################
### code chunk number 41: syntab.mupa
###################################################
syntab(elbaue, clust, mupa=TRUE, fullnames=TRUE)


###################################################
### code chunk number 42: vegdata.Rnw:480-482
###################################################
library(googleVis)
site.coord$loc <- paste(site.coord[,29], site.coord[,28], sep=':')


###################################################
### code chunk number 43: vegdata.Rnw:486-494 (eval = FALSE)
###################################################
## library(rgdal)
## coord <- data.frame(HW=as.numeric(site.coord$Nordkoordinate), RW=as.numeric(site.coord$Ostkoordinate))
## coordinates(coord) <- c("RW", "HW")
## proj4string(coord) <- CRSargs(CRS("+init=epsg:31468")) # GK, 4. Stripe
## coord <- spTransform(coord, CRS("+init=epsg:4326")) # WGS 84, geographical coordinates, decimal degrees
## site.coord$long <- coordinates(coord)[,1]
## site.coord$lat <- coordinates(coord)[,2]
## site.coord$loc <- paste(site.coord$lat, site.coord$long, sep=':')


###################################################
### code chunk number 44: vegdata.Rnw:498-499
###################################################
site.coord$tip <- paste(paste('Releve_NR:', site.coord$RELEVE_NR), paste('Table:',site.coord$TABLE_NR), paste('Nr. in table:', site.coord$NR_IN_TAB), site.coord$DATE, landuse=site.coord$NUTZUNG, site.coord$Assoziation, site.coord$Erheber, paste('Locality:', site.coord[,26]), paste('Longitude:', site.coord[,28]), paste('Latitude:', site.coord[,29]), sep='<BR>')


###################################################
### code chunk number 45: vegdata.Rnw:502-504 (eval = FALSE)
###################################################
## places <- gvisMap(site.coord, 'loc', 'tip', options=list(showTip=TRUE, showLine=FALSE, enableScrollWheel=TRUE, mapType='hybrid', useMapTypeControl=TRUE, width=1000, height=800))
## plot(places)


###################################################
### code chunk number 46: nmds
###################################################
## Data analyses
library(vegan)
veg.nmds <- metaMDS(elbaue, distance = "bray", trymax = 5, autotransform =FALSE, noshare = 1, expand = TRUE, trace = 2)
# plot(veg.nmds)


###################################################
### code chunk number 47: nmdsplotfun
###################################################
library(labdsv)
library(akima)
color = function(x)rev(topo.colors(x))
nmds.plot <- function(ordi, site, var1, var2, disp, plottitle =  'NMDS', ...) {
 lplot <- nrow(ordi$points);  lspc <- nrow(ordi$species)
 filled.contour(interp(ordi$points[, 1], ordi$points[, 2], site[, var1]), ylim = c(-1, 1.1), xlim = c(-1.4, 1.4),
   color.palette = color, xlab = var1, ylab = var2, main = plottitle,
    key.title = title(main = var1, cex.main = 0.8, line = 1, xpd = NA),
    plot.axes = { axis(1);  axis(2)
      points(ordi$points[, 1], ordi$points[, 2], xlab = "", ylab = "", cex= .5, col = 2, pch = '+')
      points(ordi$species[, 1], ordi$species[, 2], xlab = "", ylab = "", cex=.2, pch = 19)
      ordisurf(ordi, site[, var2], col = 'black', choices = c(1, 2), add = TRUE)
      orditorp(ordi, display = disp, pch = " ")
      legend("topright", paste("GAM of ", var2), col = 'black', lty = 1)
   }
  ,...)
}


###################################################
### code chunk number 48: nmdsplot
###################################################
print(nmds.plot(veg.nmds, elbaue.env, disp='species', var1="MGL", var2="SDGL", plottitle = 'NMDS of Elbaue floodplain vegetation'))


